pub struct RasterMetrics {
pub width: u16,
pub height: u16,
pub bearing_x: i16,
pub bearing_y: i16,
}Expand description
Metadata for a rasterized glyph (no pixel data).
Returned by rasterization to communicate bitmap dimensions and bearing offsets.
Fields
width: u16Width of the rasterized glyph (pixels).
height: u16Height of the rasterized glyph (pixels).
bearing_x: i16Horizontal bearing (offset from glyph origin to left edge of bitmap).
bearing_y: i16Vertical bearing (offset from glyph origin to top edge of bitmap).